intelmq.bots.parsers.webinspektor package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.parsers.webinspektor package

## Submodules

## intelmq.bots.parsers.webinspektor.parser module

intelmq.bots.parsers.webinspektor.parser.BOT

  alias of `intelmq.bots.parsers.webinspektor.parser.WebinspektorParserBot`

class intelmq.bots.parsers.webinspektor.parser.MyHTMLParser(*, convert_charrefs=True)

  Bases: `html.parser.HTMLParser`

  handle_data(data)
  handle_starttag(tag, attrs)
  lsData = ''

class intelmq.bots.parsers.webinspektor.parser.WebinspektorParserBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.ParserBot`

  Parse the Web Inspektor

  process()

## Module contents